@@ -186,15 +186,15 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudformation
-import aws_cdk.aws_codepipeline
-import aws_cdk.aws_events
-import aws_cdk.aws_iam
-import aws_cdk.aws_s3
-import aws_cdk.core
+import aws_cdk.aws_cloudformation as _aws_cdk_aws_cloudformation_6e482e6f
+import aws_cdk.aws_codepipeline as _aws_cdk_aws_codepipeline_0063e444
+import aws_cdk.aws_events as _aws_cdk_aws_events_efcdfa54
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_940a1ce0
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_55f001a5
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
-@jsii.implements(aws_cdk.aws_codepipeline.IAction)
+@jsii.implements(_aws_cdk_aws_codepipeline_0063e444.IAction)
 class PipelineDeployStackAction(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/app-delivery.PipelineDeployStackAction",
@@ -304,15 +304,15 @@ class PipelineDeployStackAction(
         self,
         *,
         admin_permissions: builtins.bool,
-        input: aws_cdk.aws_codepipeline.Artifact,
-        stack: aws_cdk.core.Stack,
-        capabilities: typing.Optional[typing.Sequence[aws_cdk.aws_cloudformation.CloudFormationCapabilities]] = None,
+        input: _aws_cdk_aws_codepipeline_0063e444.Artifact,
+        stack: _aws_cdk_core_f4b25747.Stack,
+        capabilities: typing.Optional[typing.Sequence[_aws_cdk_aws_cloudformation_6e482e6f.CloudFormationCapabilities]] = None,
         change_set_name: typing.Optional[builtins.str] = None,
         create_change_set_action_name: typing.Optional[builtins.str] = None,
         create_change_set_run_order: typing.Optional[jsii.Number] = None,
         execute_change_set_action_name: typing.Optional[builtins.str] = None,
         execute_change_set_run_order: typing.Optional[jsii.Number] = None,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole] = None,
     ) -> None:
         '''
         :param admin_permissions: (deprecated) Whether to grant admin permissions to CloudFormation while deploying this template. Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you don't specify any alternatives. The default role that will be created for you will have admin (i.e., ``*``) permissions on all resources, and the deployment will have named IAM capabilities (i.e., able to create all IAM resources). This is a shorthand that you can use if you fully trust the templates that are deployed in this pipeline. If you want more fine-grained permissions, use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation deployment is allowed to do.
@@ -346,7 +346,7 @@ class PipelineDeployStackAction(
     @jsii.member(jsii_name="addToDeploymentRolePolicy")
     def add_to_deployment_role_policy(
         self,
-        statement: aws_cdk.aws_iam.PolicyStatement,
+        statement: _aws_cdk_aws_iam_940a1ce0.PolicyStatement,
     ) -> None:
         '''(deprecated) Add policy statements to the role deploying the stack.
 
@@ -361,21 +361,19 @@ class PipelineDeployStackAction(
         :stability: deprecated
         '''
         if __debug__:
-            def stub(statement: aws_cdk.aws_iam.PolicyStatement) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__551c6548b8015c43ee6bc945fc69bce7f6b5c1044d362d3d6c49904ca23c689c)
             check_type(argname="argument statement", value=statement, expected_type=type_hints["statement"])
         return typing.cast(None, jsii.invoke(self, "addToDeploymentRolePolicy", [statement]))
 
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: aws_cdk.core.Construct,
-        stage: aws_cdk.aws_codepipeline.IStage,
+        scope: _aws_cdk_core_f4b25747.Construct,
+        stage: _aws_cdk_aws_codepipeline_0063e444.IStage,
         *,
-        bucket: aws_cdk.aws_s3.IBucket,
-        role: aws_cdk.aws_iam.IRole,
-    ) -> aws_cdk.aws_codepipeline.ActionConfig:
+        bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
+        role: _aws_cdk_aws_iam_940a1ce0.IRole,
+    ) -> _aws_cdk_aws_codepipeline_0063e444.ActionConfig:
         '''(deprecated) The callback invoked when this Action is added to a Pipeline.
 
         :param scope: -
@@ -386,35 +384,29 @@ class PipelineDeployStackAction(
         :stability: deprecated
         '''
         if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                stage: aws_cdk.aws_codepipeline.IStage,
-                *,
-                bucket: aws_cdk.aws_s3.IBucket,
-                role: aws_cdk.aws_iam.IRole,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a2bc0ce9e9abe819af4024e04338eb87c9b17f7f0aae3705e68980e8dda4ff9e)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument stage", value=stage, expected_type=type_hints["stage"])
-        options = aws_cdk.aws_codepipeline.ActionBindOptions(bucket=bucket, role=role)
+        options = _aws_cdk_aws_codepipeline_0063e444.ActionBindOptions(
+            bucket=bucket, role=role
+        )
 
-        return typing.cast(aws_cdk.aws_codepipeline.ActionConfig, jsii.invoke(self, "bind", [scope, stage, options]))
+        return typing.cast(_aws_cdk_aws_codepipeline_0063e444.ActionConfig, jsii.invoke(self, "bind", [scope, stage, options]))
 
     @jsii.member(jsii_name="onStateChange")
     def on_state_change(
         self,
         name: builtins.str,
-        target: typing.Optional[aws_cdk.aws_events.IRuleTarget] = None,
+        target: typing.Optional[_aws_cdk_aws_events_efcdfa54.IRuleTarget] = None,
         *,
         description: typing.Optional[builtins.str] = None,
         enabled: typing.Optional[builtins.bool] = None,
-        event_bus: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        event_pattern: typing.Optional[typing.Union[aws_cdk.aws_events.EventPattern, typing.Dict[str, typing.Any]]] = None,
+        event_bus: typing.Optional[_aws_cdk_aws_events_efcdfa54.IEventBus] = None,
+        event_pattern: typing.Optional[typing.Union[_aws_cdk_aws_events_efcdfa54.EventPattern, typing.Dict[builtins.str, typing.Any]]] = None,
         rule_name: typing.Optional[builtins.str] = None,
-        schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
-        targets: typing.Optional[typing.Sequence[aws_cdk.aws_events.IRuleTarget]] = None,
-    ) -> aws_cdk.aws_events.Rule:
+        schedule: typing.Optional[_aws_cdk_aws_events_efcdfa54.Schedule] = None,
+        targets: typing.Optional[typing.Sequence[_aws_cdk_aws_events_efcdfa54.IRuleTarget]] = None,
+    ) -> _aws_cdk_aws_events_efcdfa54.Rule:
         '''(deprecated) Creates an Event that will be triggered whenever the state of this Action changes.
 
         :param name: -
@@ -430,23 +422,10 @@ class PipelineDeployStackAction(
         :stability: deprecated
         '''
         if __debug__:
-            def stub(
-                name: builtins.str,
-                target: typing.Optional[aws_cdk.aws_events.IRuleTarget] = None,
-                *,
-                description: typing.Optional[builtins.str] = None,
-                enabled: typing.Optional[builtins.bool] = None,
-                event_bus: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                event_pattern: typing.Optional[typing.Union[aws_cdk.aws_events.EventPattern, typing.Dict[str, typing.Any]]] = None,
-                rule_name: typing.Optional[builtins.str] = None,
-                schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
-                targets: typing.Optional[typing.Sequence[aws_cdk.aws_events.IRuleTarget]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__40d8fec746009ffcf86a8fb3903691ce859ed2719a6c414f7c9fd1991fb103f8)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
-        options = aws_cdk.aws_events.RuleProps(
+        options = _aws_cdk_aws_events_efcdfa54.RuleProps(
             description=description,
             enabled=enabled,
             event_bus=event_bus,
@@ -456,26 +435,26 @@ class PipelineDeployStackAction(
             targets=targets,
         )
 
-        return typing.cast(aws_cdk.aws_events.Rule, jsii.invoke(self, "onStateChange", [name, target, options]))
+        return typing.cast(_aws_cdk_aws_events_efcdfa54.Rule, jsii.invoke(self, "onStateChange", [name, target, options]))
 
     @builtins.property
     @jsii.member(jsii_name="actionProperties")
-    def action_properties(self) -> aws_cdk.aws_codepipeline.ActionProperties:
+    def action_properties(self) -> _aws_cdk_aws_codepipeline_0063e444.ActionProperties:
         '''(deprecated) The simple properties of the Action, like its Owner, name, etc.
 
         Note that this accessor will be called before the {@link bind} callback.
 
         :stability: deprecated
         '''
-        return typing.cast(aws_cdk.aws_codepipeline.ActionProperties, jsii.get(self, "actionProperties"))
+        return typing.cast(_aws_cdk_aws_codepipeline_0063e444.ActionProperties, jsii.get(self, "actionProperties"))
 
     @builtins.property
     @jsii.member(jsii_name="deploymentRole")
-    def deployment_role(self) -> aws_cdk.aws_iam.IRole:
+    def deployment_role(self) -> _aws_cdk_aws_iam_940a1ce0.IRole:
         '''
         :stability: deprecated
         '''
-        return typing.cast(aws_cdk.aws_iam.IRole, jsii.get(self, "deploymentRole"))
+        return typing.cast(_aws_cdk_aws_iam_940a1ce0.IRole, jsii.get(self, "deploymentRole"))
 
 
 @jsii.data_type(
@@ -499,15 +478,15 @@ class PipelineDeployStackActionProps:
         self,
         *,
         admin_permissions: builtins.bool,
-        input: aws_cdk.aws_codepipeline.Artifact,
-        stack: aws_cdk.core.Stack,
-        capabilities: typing.Optional[typing.Sequence[aws_cdk.aws_cloudformation.CloudFormationCapabilities]] = None,
+        input: _aws_cdk_aws_codepipeline_0063e444.Artifact,
+        stack: _aws_cdk_core_f4b25747.Stack,
+        capabilities: typing.Optional[typing.Sequence[_aws_cdk_aws_cloudformation_6e482e6f.CloudFormationCapabilities]] = None,
         change_set_name: typing.Optional[builtins.str] = None,
         create_change_set_action_name: typing.Optional[builtins.str] = None,
         create_change_set_run_order: typing.Optional[jsii.Number] = None,
         execute_change_set_action_name: typing.Optional[builtins.str] = None,
         execute_change_set_run_order: typing.Optional[jsii.Number] = None,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole] = None,
     ) -> None:
         '''
         :param admin_permissions: (deprecated) Whether to grant admin permissions to CloudFormation while deploying this template. Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you don't specify any alternatives. The default role that will be created for you will have admin (i.e., ``*``) permissions on all resources, and the deployment will have named IAM capabilities (i.e., able to create all IAM resources). This is a shorthand that you can use if you fully trust the templates that are deployed in this pipeline. If you want more fine-grained permissions, use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation deployment is allowed to do.
@@ -614,21 +593,7 @@ class PipelineDeployStackActionProps:
             ))
         '''
         if __debug__:
-            def stub(
-                *,
-                admin_permissions: builtins.bool,
-                input: aws_cdk.aws_codepipeline.Artifact,
-                stack: aws_cdk.core.Stack,
-                capabilities: typing.Optional[typing.Sequence[aws_cdk.aws_cloudformation.CloudFormationCapabilities]] = None,
-                change_set_name: typing.Optional[builtins.str] = None,
-                create_change_set_action_name: typing.Optional[builtins.str] = None,
-                create_change_set_run_order: typing.Optional[jsii.Number] = None,
-                execute_change_set_action_name: typing.Optional[builtins.str] = None,
-                execute_change_set_run_order: typing.Optional[jsii.Number] = None,
-                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c3b1fa10779593ce89fb572f766e71e388de454d1438b483dc820e6da700cd4f)
             check_type(argname="argument admin_permissions", value=admin_permissions, expected_type=type_hints["admin_permissions"])
             check_type(argname="argument input", value=input, expected_type=type_hints["input"])
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
@@ -639,7 +604,7 @@ class PipelineDeployStackActionProps:
             check_type(argname="argument execute_change_set_action_name", value=execute_change_set_action_name, expected_type=type_hints["execute_change_set_action_name"])
             check_type(argname="argument execute_change_set_run_order", value=execute_change_set_run_order, expected_type=type_hints["execute_change_set_run_order"])
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "admin_permissions": admin_permissions,
             "input": input,
             "stack": stack,
@@ -682,29 +647,29 @@ class PipelineDeployStackActionProps:
         return typing.cast(builtins.bool, result)
 
     @builtins.property
-    def input(self) -> aws_cdk.aws_codepipeline.Artifact:
+    def input(self) -> _aws_cdk_aws_codepipeline_0063e444.Artifact:
         '''(deprecated) The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
 
         :stability: deprecated
         '''
         result = self._values.get("input")
         assert result is not None, "Required property 'input' is missing"
-        return typing.cast(aws_cdk.aws_codepipeline.Artifact, result)
+        return typing.cast(_aws_cdk_aws_codepipeline_0063e444.Artifact, result)
 
     @builtins.property
-    def stack(self) -> aws_cdk.core.Stack:
+    def stack(self) -> _aws_cdk_core_f4b25747.Stack:
         '''(deprecated) The CDK stack to be deployed.
 
         :stability: deprecated
         '''
         result = self._values.get("stack")
         assert result is not None, "Required property 'stack' is missing"
-        return typing.cast(aws_cdk.core.Stack, result)
+        return typing.cast(_aws_cdk_core_f4b25747.Stack, result)
 
     @builtins.property
     def capabilities(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudformation.CloudFormationCapabilities]]:
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_cloudformation_6e482e6f.CloudFormationCapabilities]]:
         '''(deprecated) Acknowledge certain changes made as part of deployment.
 
         For stacks that contain certain resources, explicit acknowledgement that AWS CloudFormation
@@ -718,7 +683,7 @@ class PipelineDeployStackActionProps:
         :stability: deprecated
         '''
         result = self._values.get("capabilities")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudformation.CloudFormationCapabilities]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_cloudformation_6e482e6f.CloudFormationCapabilities]], result)
 
     @builtins.property
     def change_set_name(self) -> typing.Optional[builtins.str]:
@@ -776,7 +741,7 @@ class PipelineDeployStackActionProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+    def role(self) -> typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole]:
         '''(deprecated) IAM role to assume when deploying changes.
 
         If not specified, a fresh role is created. The role is created with zero
@@ -788,7 +753,7 @@ class PipelineDeployStackActionProps:
         :stability: deprecated
         '''
         result = self._values.get("role")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -808,3 +773,50 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__551c6548b8015c43ee6bc945fc69bce7f6b5c1044d362d3d6c49904ca23c689c(
+    statement: _aws_cdk_aws_iam_940a1ce0.PolicyStatement,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a2bc0ce9e9abe819af4024e04338eb87c9b17f7f0aae3705e68980e8dda4ff9e(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    stage: _aws_cdk_aws_codepipeline_0063e444.IStage,
+    *,
+    bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
+    role: _aws_cdk_aws_iam_940a1ce0.IRole,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__40d8fec746009ffcf86a8fb3903691ce859ed2719a6c414f7c9fd1991fb103f8(
+    name: builtins.str,
+    target: typing.Optional[_aws_cdk_aws_events_efcdfa54.IRuleTarget] = None,
+    *,
+    description: typing.Optional[builtins.str] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    event_bus: typing.Optional[_aws_cdk_aws_events_efcdfa54.IEventBus] = None,
+    event_pattern: typing.Optional[typing.Union[_aws_cdk_aws_events_efcdfa54.EventPattern, typing.Dict[builtins.str, typing.Any]]] = None,
+    rule_name: typing.Optional[builtins.str] = None,
+    schedule: typing.Optional[_aws_cdk_aws_events_efcdfa54.Schedule] = None,
+    targets: typing.Optional[typing.Sequence[_aws_cdk_aws_events_efcdfa54.IRuleTarget]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c3b1fa10779593ce89fb572f766e71e388de454d1438b483dc820e6da700cd4f(
+    *,
+    admin_permissions: builtins.bool,
+    input: _aws_cdk_aws_codepipeline_0063e444.Artifact,
+    stack: _aws_cdk_core_f4b25747.Stack,
+    capabilities: typing.Optional[typing.Sequence[_aws_cdk_aws_cloudformation_6e482e6f.CloudFormationCapabilities]] = None,
+    change_set_name: typing.Optional[builtins.str] = None,
+    create_change_set_action_name: typing.Optional[builtins.str] = None,
+    create_change_set_run_order: typing.Optional[jsii.Number] = None,
+    execute_change_set_action_name: typing.Optional[builtins.str] = None,
+    execute_change_set_run_order: typing.Optional[jsii.Number] = None,
+    role: typing.Optional[_aws_cdk_aws_iam_940a1ce0.IRole] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
